package com.zhongdao.jlr.business.dao;

import com.dubh.common.dao.Dao;
import com.util.Vo;
import com.zhongdao.jlr.business.vo.Contract;
import com.zhongdao.jlr.business.vo.Destination;
import com.zhongdao.jlr.business.vo.Enterprise;
import com.zhongdao.jlr.pojo.JLRDestination;
import com.zhongdao.jlr.pojo.JLRSupplier;
import com.zhongdao.jlr.pojo.JLRUserContract;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/***
 * 接口
 */
public interface SupplierDao extends Dao{

    /***
     * 获取合同信息并分页展示
     * @param request
     * @return
     */
    Vo getContractInfo(HttpServletRequest request,String name,String id);

    /***
     * 获取指定的合同信息
     * @return
     */
    List<Contract> getAssignContract(String id);

    /***
     * 获取指定的目的地信息
     * @param id
     * @return
     */
    List<Destination> getAssignDestination(String id);

    /***
     * 获取指定的供应商信息
     * @param id
     * @return
     */
    List<Enterprise> getAssignEnterprise(String id);

    /***
     * 获取供应商信息并分页展示
     * @param request
     * @return
     */
    Vo getEnterpriseInfo(HttpServletRequest request,String name,String id);


    /***
     * 获取合同下的目的地信息并分页展示
     * @param request
     * @return
     */
    Vo getDestination(HttpServletRequest request,String name,String id);

    /***
     * 为用户指定合同
     * @return
     */
    boolean insertContractInfo(JLRUserContract jlrUserContract);

    /***
     * 指定目的地
     * @return
     */
    boolean insertDestinationInfo(JLRDestination jlrDestination);

    /***
     * 指定供应商
     * @return
     */
    boolean insertEnterpriseInfo(JLRSupplier jlrSupplier);

    /***
     * 删除指定的合同
     * @return
     */
    boolean deleteContractInfo(int cid,int id);

    /***
     * 删除指定的供应商
     * @return
     */
    boolean deleteEnterpriseInfo(int sid,int id);

    /***
     * 删除指定的目的地
     * @return
     */
    boolean deleteDestinationInfo(int did,int id);

    /***
     *根据用户id获取合同信息
     * @param id
     * @return
     */
    List<JLRUserContract> getContract(String id);
}
